import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ConfigOrganizationConformancePackConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_organization_conformance_pack.html#delivery_s3_bucket ConfigOrganizationConformancePack#delivery_s3_bucket}.
     *
     * @stability stable
     */
    readonly deliveryS3Bucket?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_organization_conformance_pack.html#delivery_s3_key_prefix ConfigOrganizationConformancePack#delivery_s3_key_prefix}.
     *
     * @stability stable
     */
    readonly deliveryS3KeyPrefix?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_organization_conformance_pack.html#excluded_accounts ConfigOrganizationConformancePack#excluded_accounts}.
     *
     * @stability stable
     */
    readonly excludedAccounts?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_organization_conformance_pack.html#name ConfigOrganizationConformancePack#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_organization_conformance_pack.html#template_body ConfigOrganizationConformancePack#template_body}.
     *
     * @stability stable
     */
    readonly templateBody?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_organization_conformance_pack.html#template_s3_uri ConfigOrganizationConformancePack#template_s3_uri}.
     *
     * @stability stable
     */
    readonly templateS3Uri?: string;
    /**
     * input_parameter block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_organization_conformance_pack.html#input_parameter ConfigOrganizationConformancePack#input_parameter}
     *
     * @stability stable
     */
    readonly inputParameter?: ConfigOrganizationConformancePackInputParameter[];
}
/**
 * @stability stable
 */
export interface ConfigOrganizationConformancePackInputParameter {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_organization_conformance_pack.html#parameter_name ConfigOrganizationConformancePack#parameter_name}.
     *
     * @stability stable
     */
    readonly parameterName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_organization_conformance_pack.html#parameter_value ConfigOrganizationConformancePack#parameter_value}.
     *
     * @stability stable
     */
    readonly parameterValue: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/config_organization_conformance_pack.html aws_config_organization_conformance_pack}.
 *
 * @stability stable
 */
export declare class ConfigOrganizationConformancePack extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/config_organization_conformance_pack.html aws_config_organization_conformance_pack} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ConfigOrganizationConformancePackConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _deliveryS3Bucket?;
    /**
     * @stability stable
     */
    get deliveryS3Bucket(): string;
    /**
     * @stability stable
     */
    set deliveryS3Bucket(value: string);
    /**
     * @stability stable
     */
    resetDeliveryS3Bucket(): void;
    /**
     * @stability stable
     */
    get deliveryS3BucketInput(): string | undefined;
    private _deliveryS3KeyPrefix?;
    /**
     * @stability stable
     */
    get deliveryS3KeyPrefix(): string;
    /**
     * @stability stable
     */
    set deliveryS3KeyPrefix(value: string);
    /**
     * @stability stable
     */
    resetDeliveryS3KeyPrefix(): void;
    /**
     * @stability stable
     */
    get deliveryS3KeyPrefixInput(): string | undefined;
    private _excludedAccounts?;
    /**
     * @stability stable
     */
    get excludedAccounts(): string[];
    /**
     * @stability stable
     */
    set excludedAccounts(value: string[]);
    /**
     * @stability stable
     */
    resetExcludedAccounts(): void;
    /**
     * @stability stable
     */
    get excludedAccountsInput(): string[] | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _templateBody?;
    /**
     * @stability stable
     */
    get templateBody(): string;
    /**
     * @stability stable
     */
    set templateBody(value: string);
    /**
     * @stability stable
     */
    resetTemplateBody(): void;
    /**
     * @stability stable
     */
    get templateBodyInput(): string | undefined;
    private _templateS3Uri?;
    /**
     * @stability stable
     */
    get templateS3Uri(): string;
    /**
     * @stability stable
     */
    set templateS3Uri(value: string);
    /**
     * @stability stable
     */
    resetTemplateS3Uri(): void;
    /**
     * @stability stable
     */
    get templateS3UriInput(): string | undefined;
    private _inputParameter?;
    /**
     * @stability stable
     */
    get inputParameter(): ConfigOrganizationConformancePackInputParameter[];
    /**
     * @stability stable
     */
    set inputParameter(value: ConfigOrganizationConformancePackInputParameter[]);
    /**
     * @stability stable
     */
    resetInputParameter(): void;
    /**
     * @stability stable
     */
    get inputParameterInput(): ConfigOrganizationConformancePackInputParameter[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
